"""
Class object for Cpu
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:02:07.950442
"""
from .base import BridgeBase


class Cache(BridgeBase):
    @property
    def l1d(self):
        return self.attributes.get("l1d", None)

    @property
    def l1i(self):
        return self.attributes.get("l1i", None)

    @property
    def l2(self):
        return self.attributes.get("l2", None)

    @property
    def l3(self):
        return self.attributes.get("l3", None)


class CpuCache(BridgeBase):
    @property
    def l1d(self):
        return self.attributes.get("l1d", None)

    @property
    def l1i(self):
        return self.attributes.get("l1i", None)

    @property
    def l2(self):
        return self.attributes.get("l2", None)

    @property
    def l3(self):
        return self.attributes.get("l3", None)


class CpuInner(BridgeBase):
    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def brand(self):
        return self.attributes.get("brand", "")

    @property
    def vendor(self):
        return self.attributes.get("vendor", "")

    @property
    def family(self):
        return self.attributes.get("family", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def stepping(self):
        return self.attributes.get("stepping", "")

    @property
    def revision(self):
        return self.attributes.get("revision", "")

    @property
    def voltage(self):
        return self.attributes.get("voltage", "")

    @property
    def speed(self):
        return self.attributes.get("speed", None)

    @property
    def speedMin(self):
        return self.attributes.get("speedMin", None)

    @property
    def speedMax(self):
        return self.attributes.get("speedMax", None)

    @property
    def governor(self):
        return self.attributes.get("governor", "")

    @property
    def cores(self):
        return self.attributes.get("cores", None)

    @property
    def physicalCores(self):
        return self.attributes.get("physicalCores", None)

    @property
    def processors(self):
        return self.attributes.get("processors", None)

    @property
    def socket(self):
        return self.attributes.get("socket", "")

    @property
    def flags(self):
        return self.attributes.get("flags", "")

    @property
    def virtualization(self):
        return self.attributes.get("virtualization", False)

    @property
    def cache(self):
        return CpuCache(self.attributes.get("cache", {}))


class CurrentSpeed(BridgeBase):
    @property
    def min(self):
        return self.attributes.get("min", None)

    @property
    def max(self):
        return self.attributes.get("max", None)

    @property
    def avg(self):
        return self.attributes.get("avg", None)

    @property
    def cores(self):
        return self.attributes.get("cores", None)


class Temperature(BridgeBase):
    @property
    def main(self):
        return self.attributes.get("main", None)

    @property
    def max(self):
        return self.attributes.get("max", None)


class Cpu(BridgeBase):
    @property
    def cache(self):
        return Cache(self.attributes.get("cache", {}))

    @property
    def cpu(self):
        return CpuInner(self.attributes.get("cpu", {}))

    @property
    def currentSpeed(self):
        return CurrentSpeed(self.attributes.get("currentSpeed", {}))

    @property
    def temperature(self):
        return Temperature(self.attributes.get("temperature", {}))



"""Bridge: Init"""
from aiohttp import ClientResponse
from typing import Any, List

from .client import BridgeClient
from .objects.audio import Audio
from .objects.base import BridgeBase
from .objects.battery import Battery
from .objects.bluetooth import Bluetooth
from .objects.command.payload import CommandPayload
from .objects.command.response import CommandResponse
from .objects.cpu import Cpu
from .objects.filesystem import Filesystem
from .objects.graphics import Graphics
from .objects.information import Information
from .objects.memory import Memory
from .objects.network import Network
from .objects.os import Os
from .objects.processes import Processes
from .objects.system import System

BASE_HEADERS = {"Accept": "application/json"}


class Bridge(BridgeBase):
    """Main class for Bridge."""

    def __init__(self, client: BridgeClient, base_url: str, api_key: str) -> None:
        """Initialize the token manager class."""
        self._client = client
        self._base_url = base_url
        self._api_key = api_key
        self._audio: List[Audio] = []
        self._battery: Battery = {}
        self._bluetooth: Bluetooth = {}
        self._cpu: Cpu = {}
        self._filesystem: Filesystem = {}
        self._graphics: Graphics = {}
        self._information: Information = {}
        self._memory: Memory = {}
        self._os: Os = {}
        self._processes: Processes = {}
        self._system: System = {}

    @property
    def audio(self) -> List[Audio]:
        return self._audio

    @property
    def battery(self) -> Battery:
        return self._battery

    @property
    def bluetooth(self) -> Bluetooth:
        return self._bluetooth

    @property
    def cpu(self) -> Cpu:
        return self._cpu

    @property
    def filesystem(self) -> Filesystem:
        return self._filesystem

    @property
    def graphics(self) -> Graphics:
        return self._graphics

    @property
    def information(self) -> Information:
        return self._information

    @property
    def memory(self) -> Memory:
        return self._memory

    @property
    def network(self) -> Network:
        return self._network

    @property
    def os(self) -> Os:
        return self._os

    @property
    def processes(self) -> Processes:
        return self._processes

    @property
    def system(self) -> System:
        return self._system

    async def async_get(self, path: str) -> Any:
        """Generic Getter"""
        response: ClientResponse = await self._client.get(
            f"{self._base_url}{path}",
            headers={**BASE_HEADERS, "api-key": self._api_key},
        )
        return await response.json()

    async def async_post(self, path: str, payload: Any) -> Any:
        """Generic Getter"""
        response: ClientResponse = await self._client.post(
            f"{self._base_url}{path}",
            headers={**BASE_HEADERS, "api-key": self._api_key},
            json=payload,
        )
        return await response.json()

    async def async_get_audio(self) -> List[Audio]:
        """Get audio information"""
        self._audio = [Audio(audio) for audio in await self.async_get("/audio") or []]
        return self._audio

    async def async_get_battery(self) -> Battery:
        """Get battery information"""
        self._battery = Battery(await self.async_get("/battery"))
        return self._battery

    async def async_get_bluetooth(self) -> Bluetooth:
        """Get bluetooth information"""
        self._bluetooth = Bluetooth(await self.async_get("/bluetooth"))
        return self._bluetooth

    async def async_send_command(self, payload: CommandPayload) -> CommandResponse:
        """Get cpu information"""
        return CommandResponse(await self.async_post("/command", payload))

    async def async_get_cpu(self) -> Cpu:
        """Get cpu information"""
        self._cpu = Cpu(await self.async_get("/cpu"))
        return self._cpu

    async def async_get_filesystem(self) -> Filesystem:
        """Get filesystem information"""
        self._filesystem = Filesystem(await self.async_get("/filesystem"))
        return self._filesystem

    async def async_get_graphics(self) -> Graphics:
        """Get graphics information"""
        self._graphics = Graphics(await self.async_get("/graphics"))
        return self._graphics

    async def async_get_information(self) -> Information:
        """Get information"""
        self._information = Information(await self.async_get("/information"))
        return self._information

    async def async_get_memory(self) -> Memory:
        """Get memory information"""
        self._memory = Memory(await self.async_get("/memory"))
        return self._memory

    async def async_get_network(self) -> Network:
        """Get network information"""
        self._network = Network(await self.async_get("/network"))
        return self._network

    async def async_get_os(self) -> Os:
        """Get os information"""
        self._os = Os(await self.async_get("/os"))
        return self._os

    async def async_get_processes(self) -> Processes:
        """Get processes information"""
        self._processes = Processes(await self.async_get("/processes"))
        return self._processes

    async def async_get_system(self) -> System:
        """Get system information"""
        self._system = System(await self.async_get("/system"))
        return self._system



"""
Class object for BridgeInformation
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 16:41:50.490343
"""
from .base import BridgeBase


class Endpoint(BridgeBase):
    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def endpoint(self):
        return self.attributes.get("endpoint", "")


class Information(BridgeBase):
    @property
    def audio(self):
        return Endpoint(self.attributes.get("audio", {}))

    @property
    def battery(self):
        return Endpoint(self.attributes.get("battery", {}))

    @property
    def bluetooth(self):
        return Endpoint(self.attributes.get("bluetooth", {}))

    @property
    def command(self):
        return Endpoint(self.attributes.get("command", {}))

    @property
    def cpu(self):
        return Endpoint(self.attributes.get("cpu", {}))

    @property
    def docs(self):
        return Endpoint(self.attributes.get("docs", {}))

    @property
    def filesystem(self):
        return Endpoint(self.attributes.get("filesystem", {}))

    @property
    def graphics(self):
        return Endpoint(self.attributes.get("graphics", {}))

    @property
    def information(self):
        return Endpoint(self.attributes.get("information", {}))

    @property
    def memory(self):
        return Endpoint(self.attributes.get("memory", {}))

    @property
    def network(self):
        return Endpoint(self.attributes.get("network", {}))

    @property
    def os(self):
        return Endpoint(self.attributes.get("os", {}))

    @property
    def system(self):
        return Endpoint(self.attributes.get("system", {}))



"""
Class object for BridgeBluetooth
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 16:50:21.146717
"""
from .base import BridgeBase


class Bluetooth(BridgeBase):
    @property
    def device(self):
        return self.attributes.get("device", "")

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def macDevice(self):
        return self.attributes.get("macDevice", "")

    @property
    def macHost(self):
        return self.attributes.get("macHost", "")

    @property
    def batteryPercent(self):
        return self.attributes.get("batteryPercent", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def connected(self):
        return self.attributes.get("connected", "")



"""
Class object for Processes
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-21 13:16:34.619813
"""
from .base import BridgeBase


class ProccessList(BridgeBase):
    @property
    def pid(self):
        return self.attributes.get("pid", None)

    @property
    def parentPid(self):
        return self.attributes.get("parentPid", None)

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def cpu(self):
        return self.attributes.get("cpu", None)

    @property
    def cpuu(self):
        return self.attributes.get("cpuu", None)

    @property
    def cpus(self):
        return self.attributes.get("cpus", None)

    @property
    def mem(self):
        return self.attributes.get("mem", None)

    @property
    def priority(self):
        return self.attributes.get("priority", None)

    @property
    def memVsz(self):
        return self.attributes.get("memVsz", None)

    @property
    def memRss(self):
        return self.attributes.get("memRss", None)

    @property
    def nice(self):
        return self.attributes.get("nice", None)

    @property
    def started(self):
        return self.attributes.get("started", "")

    @property
    def state(self):
        return self.attributes.get("state", "")

    @property
    def tty(self):
        return self.attributes.get("tty", "")

    @property
    def user(self):
        return self.attributes.get("user", "")

    @property
    def command(self):
        return self.attributes.get("command", "")

    @property
    def params(self):
        return self.attributes.get("params", "")

    @property
    def path(self):
        return self.attributes.get("path", "")


class Cpus(BridgeBase):
    @property
    def load(self):
        return self.attributes.get("load", None)

    @property
    def loadUser(self):
        return self.attributes.get("loadUser", None)

    @property
    def loadSystem(self):
        return self.attributes.get("loadSystem", None)

    @property
    def loadNice(self):
        return self.attributes.get("loadNice", None)

    @property
    def loadIdle(self):
        return self.attributes.get("loadIdle", None)

    @property
    def loadIrq(self):
        return self.attributes.get("loadIrq", None)

    @property
    def rawLoad(self):
        return self.attributes.get("rawLoad", None)

    @property
    def rawLoadUser(self):
        return self.attributes.get("rawLoadUser", None)

    @property
    def rawLoadSystem(self):
        return self.attributes.get("rawLoadSystem", None)

    @property
    def rawLoadNice(self):
        return self.attributes.get("rawLoadNice", None)

    @property
    def rawLoadIdle(self):
        return self.attributes.get("rawLoadIdle", None)

    @property
    def rawLoadIrq(self):
        return self.attributes.get("rawLoadIrq", None)


class Load(BridgeBase):
    @property
    def avgLoad(self):
        return self.attributes.get("avgLoad", None)

    @property
    def currentLoad(self):
        return self.attributes.get("currentLoad", None)

    @property
    def currentLoadUser(self):
        return self.attributes.get("currentLoadUser", None)

    @property
    def currentLoadSystem(self):
        return self.attributes.get("currentLoadSystem", None)

    @property
    def currentLoadNice(self):
        return self.attributes.get("currentLoadNice", None)

    @property
    def currentLoadIdle(self):
        return self.attributes.get("currentLoadIdle", None)

    @property
    def currentLoadIrq(self):
        return self.attributes.get("currentLoadIrq", None)

    @property
    def rawCurrentLoad(self):
        return self.attributes.get("rawCurrentLoad", None)

    @property
    def rawCurrentLoadUser(self):
        return self.attributes.get("rawCurrentLoadUser", None)

    @property
    def rawCurrentLoadSystem(self):
        return self.attributes.get("rawCurrentLoadSystem", None)

    @property
    def rawCurrentLoadNice(self):
        return self.attributes.get("rawCurrentLoadNice", None)

    @property
    def rawCurrentLoadIdle(self):
        return self.attributes.get("rawCurrentLoadIdle", None)

    @property
    def rawCurrentLoadIrq(self):
        return self.attributes.get("rawCurrentLoadIrq", None)

    @property
    def cpus(self):
        return [Cpus(x) for x in self.attributes.get("cpus", [])]


class Processes(BridgeBase):
    @property
    def all(self):
        return self.attributes.get("all", None)

    @property
    def running(self):
        return self.attributes.get("running", None)

    @property
    def blocked(self):
        return self.attributes.get("blocked", None)

    @property
    def sleeping(self):
        return self.attributes.get("sleeping", None)

    @property
    def unknown(self):
        return self.attributes.get("unknown", None)

    @property
    def proccessList(self):
        return [ProccessList(x) for x in self.attributes.get("list", [])]

    @property
    def load(self):
        return Load(self.attributes.get("load", {}))



"""
Class object for Network
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 22:32:33.713877
"""
from typing import Dict, Optional
from .base import BridgeBase


class Connections(BridgeBase):
    @property
    def protocol(self):
        return self.attributes.get("protocol", "")

    @property
    def localAddress(self):
        return self.attributes.get("localAddress", "")

    @property
    def localPort(self):
        return self.attributes.get("localPort", "")

    @property
    def peerAddress(self):
        return self.attributes.get("peerAddress", "")

    @property
    def peerPort(self):
        return self.attributes.get("peerPort", "")

    @property
    def state(self):
        return self.attributes.get("state", "")

    @property
    def pid(self):
        return self.attributes.get("pid", "")

    @property
    def process(self):
        return self.attributes.get("process", "")


class Interface(BridgeBase):
    @property
    def iface(self):
        return self.attributes.get("iface", "")

    @property
    def ifaceName(self):
        return self.attributes.get("ifaceName", "")

    @property
    def ip4(self):
        return self.attributes.get("ip4", "")

    @property
    def ip4subnet(self):
        return self.attributes.get("ip4subnet", "")

    @property
    def ip6(self):
        return self.attributes.get("ip6", "")

    @property
    def ip6subnet(self):
        return self.attributes.get("ip6subnet", "")

    @property
    def mac(self):
        return self.attributes.get("mac", "")

    @property
    def internal(self):
        return self.attributes.get("internal", False)

    @property
    def virtual(self):
        return self.attributes.get("virtual", False)

    @property
    def operstate(self):
        return self.attributes.get("operstate", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def duplex(self):
        return self.attributes.get("duplex", "")

    @property
    def mtu(self):
        return self.attributes.get("mtu", "")

    @property
    def speed(self):
        return self.attributes.get("speed", None)

    @property
    def dhcp(self):
        return self.attributes.get("dhcp", "")

    @property
    def dnsSuffix(self):
        return self.attributes.get("dnsSuffix", "")

    @property
    def ieee8021xAuth(self):
        return self.attributes.get("ieee8021xAuth", "")

    @property
    def ieee8021xState(self):
        return self.attributes.get("ieee8021xState", "")

    @property
    def carrierChanges(self):
        return self.attributes.get("carrierChanges", None)


class Stat(BridgeBase):
    @property
    def iface(self):
        return self.attributes.get("iface", "")

    @property
    def operstate(self):
        return self.attributes.get("operstate", "")

    @property
    def rx_bytes(self):
        return self.attributes.get("rx_bytes", None)

    @property
    def rx_dropped(self):
        return self.attributes.get("rx_dropped", None)

    @property
    def rx_errors(self):
        return self.attributes.get("rx_errors", None)

    @property
    def tx_bytes(self):
        return self.attributes.get("tx_bytes", None)

    @property
    def tx_dropped(self):
        return self.attributes.get("tx_dropped", None)

    @property
    def tx_errors(self):
        return self.attributes.get("tx_errors", None)

    @property
    def rx_sec(self):
        return self.attributes.get("rx_sec", None)

    @property
    def tx_sec(self):
        return self.attributes.get("tx_sec", None)

    @property
    def ms(self):
        return self.attributes.get("ms", None)


class Network(BridgeBase):
    @property
    def connections(self):
        return [Connections(x) for x in self.attributes.get("connections", [])]

    @property
    def gatewayDefault(self):
        return self.attributes.get("gatewayDefault", "")

    @property
    def interfaceDefault(self):
        return self.attributes.get("interfaceDefault", "")

    @property
    def interfaces(self) -> Optional[Dict[str, Interface]]:
        return self.attributes.get("interfaces", {})

    @property
    def stats(self) -> Optional[Dict[str, Stat]]:
        return self.attributes.get("stats", {})



"""
Class object for Os
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:09:12.868028
"""
from .base import BridgeBase


class Users(BridgeBase):
    @property
    def user(self):
        return self.attributes.get("user", "")

    @property
    def tty(self):
        return self.attributes.get("tty", "")

    @property
    def date(self):
        return self.attributes.get("date", "")

    @property
    def time(self):
        return self.attributes.get("time", "")

    @property
    def ip(self):
        return self.attributes.get("ip", "")

    @property
    def command(self):
        return self.attributes.get("command", "")


class Os(BridgeBase):
    @property
    def platform(self):
        return self.attributes.get("platform", "")

    @property
    def distro(self):
        return self.attributes.get("distro", "")

    @property
    def release(self):
        return self.attributes.get("release", "")

    @property
    def codename(self):
        return self.attributes.get("codename", "")

    @property
    def kernel(self):
        return self.attributes.get("kernel", "")

    @property
    def arch(self):
        return self.attributes.get("arch", "")

    @property
    def hostname(self):
        return self.attributes.get("hostname", "")

    @property
    def fqdn(self):
        return self.attributes.get("fqdn", "")

    @property
    def codepage(self):
        return self.attributes.get("codepage", "")

    @property
    def logofile(self):
        return self.attributes.get("logofile", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")

    @property
    def build(self):
        return self.attributes.get("build", "")

    @property
    def servicepack(self):
        return self.attributes.get("servicepack", "")

    @property
    def uefi(self):
        return self.attributes.get("uefi", False)

    @property
    def hypervisor(self):
        return self.attributes.get("hypervisor", True)

    @property
    def remoteSession(self):
        return self.attributes.get("remoteSession", False)

    @property
    def users(self):
        return [Users(x) for x in self.attributes.get("users", [])]



"""
Class object for System
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:09:39.232395
"""
from .base import BridgeBase


class Baseboard(BridgeBase):
    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def version(self):
        return self.attributes.get("version", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")

    @property
    def assetTag(self):
        return self.attributes.get("assetTag", "")

    @property
    def memMax(self):
        return self.attributes.get("memMax", None)

    @property
    def memSlots(self):
        return self.attributes.get("memSlots", None)


class Bios(BridgeBase):
    @property
    def vendor(self):
        return self.attributes.get("vendor", "")

    @property
    def version(self):
        return self.attributes.get("version", "")

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def revision(self):
        return self.attributes.get("revision", "")


class Chassis(BridgeBase):
    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def version(self):
        return self.attributes.get("version", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")

    @property
    def assetTag(self):
        return self.attributes.get("assetTag", "")

    @property
    def sku(self):
        return self.attributes.get("sku", "")


class SystemInner(BridgeBase):
    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def version(self):
        return self.attributes.get("version", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")

    @property
    def uuid(self):
        return self.attributes.get("uuid", "")

    @property
    def sku(self):
        return self.attributes.get("sku", "")

    @property
    def virtual(self):
        return self.attributes.get("virtual", False)


class Uuid(BridgeBase):
    @property
    def os(self):
        return self.attributes.get("os", "")

    @property
    def hardware(self):
        return self.attributes.get("hardware", "")

    @property
    def macs(self):
        return self.attributes.get("macs", [])


class System(BridgeBase):
    @property
    def baseboard(self):
        return Baseboard(self.attributes.get("baseboard", {}))

    @property
    def bios(self):
        return Bios(self.attributes.get("bios", {}))

    @property
    def chassis(self):
        return Chassis(self.attributes.get("chassis", {}))

    @property
    def system(self):
        return SystemInner(self.attributes.get("system", {}))

    @property
    def uuid(self):
        return Uuid(self.attributes.get("uuid", {}))



"""Bridge: Exceptions"""


class BridgeException(BaseException):
    """Raise this when something is off."""


class BridgeAuthenticationException(BridgeException):
    """Raise this when there is an authentication issue."""



"""
Class object for BridgeAudio
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 16:48:42.854477
"""
from .base import BridgeBase


class Audio(BridgeBase):
    @property
    def id(self):
        return self.attributes.get("id", "")

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def revision(self):
        return self.attributes.get("revision", "")

    @property
    def driver(self):
        return self.attributes.get("driver", "")

    @property
    def default(self):
        return self.attributes.get("default", "")

    @property
    def channel(self):
        return self.attributes.get("channel", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def p_in(self):
        return self.attributes.get("in", "")

    @property
    def out(self):
        return self.attributes.get("out", "")

    @property
    def status(self):
        return self.attributes.get("status", "")



"""
Class object for Graphics
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:07:18.274493
"""
from .base import BridgeBase


class Controllers(BridgeBase):
    @property
    def vendor(self):
        return self.attributes.get("vendor", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def bus(self):
        return self.attributes.get("bus", "")

    @property
    def vram(self):
        return self.attributes.get("vram", None)

    @property
    def vramDynamic(self):
        return self.attributes.get("vramDynamic", False)

    @property
    def subDeviceId(self):
        return self.attributes.get("subDeviceId", "")

    @property
    def driverVersion(self):
        return self.attributes.get("driverVersion", "")

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def pciBus(self):
        return self.attributes.get("pciBus", "")

    @property
    def memoryTotal(self):
        return self.attributes.get("memoryTotal", None)

    @property
    def memoryUsed(self):
        return self.attributes.get("memoryUsed", None)

    @property
    def memoryFree(self):
        return self.attributes.get("memoryFree", None)

    @property
    def utilizationGpu(self):
        return self.attributes.get("utilizationGpu", None)

    @property
    def utilizationMemory(self):
        return self.attributes.get("utilizationMemory", None)

    @property
    def temperatureGpu(self):
        return self.attributes.get("temperatureGpu", None)

    @property
    def powerDraw(self):
        return self.attributes.get("powerDraw", None)

    @property
    def powerLimit(self):
        return self.attributes.get("powerLimit", None)

    @property
    def clockCore(self):
        return self.attributes.get("clockCore", None)

    @property
    def clockMemory(self):
        return self.attributes.get("clockMemory", None)


class Displays(BridgeBase):
    @property
    def vendor(self):
        return self.attributes.get("vendor", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def deviceName(self):
        return self.attributes.get("deviceName", "")

    @property
    def main(self):
        return self.attributes.get("main", True)

    @property
    def builtin(self):
        return self.attributes.get("builtin", False)

    @property
    def connection(self):
        return self.attributes.get("connection", "")

    @property
    def resolutionX(self):
        return self.attributes.get("resolutionX", None)

    @property
    def resolutionY(self):
        return self.attributes.get("resolutionY", None)

    @property
    def sizeX(self):
        return self.attributes.get("sizeX", None)

    @property
    def sizeY(self):
        return self.attributes.get("sizeY", None)

    @property
    def pixelDepth(self):
        return self.attributes.get("pixelDepth", "")

    @property
    def currentResX(self):
        return self.attributes.get("currentResX", None)

    @property
    def currentResY(self):
        return self.attributes.get("currentResY", None)

    @property
    def positionX(self):
        return self.attributes.get("positionX", None)

    @property
    def positionY(self):
        return self.attributes.get("positionY", None)


class Graphics(BridgeBase):
    @property
    def controllers(self):
        return [Controllers(x) for x in self.attributes.get("controllers", [])]

    @property
    def displays(self):
        return [Displays(x) for x in self.attributes.get("displays", [])]



"""
Class object for Filesystem
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:05:47.607534
"""
from typing import Any, Dict, Optional
from .base import BridgeBase


class BlockDevices(BridgeBase):
    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def identifier(self):
        return self.attributes.get("identifier", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def fsType(self):
        return self.attributes.get("fsType", "")

    @property
    def mount(self):
        return self.attributes.get("mount", "")

    @property
    def size(self):
        return self.attributes.get("size", "")

    @property
    def physical(self):
        return self.attributes.get("physical", "")

    @property
    def uuid(self):
        return self.attributes.get("uuid", "")

    @property
    def label(self):
        return self.attributes.get("label", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")

    @property
    def removable(self):
        return self.attributes.get("removable", False)

    @property
    def protocol(self):
        return self.attributes.get("protocol", "")


class DiskLayout(BridgeBase):
    @property
    def device(self):
        return self.attributes.get("device", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def vendor(self):
        return self.attributes.get("vendor", "")

    @property
    def size(self):
        return self.attributes.get("size", None)

    @property
    def bytesPerSector(self):
        return self.attributes.get("bytesPerSector", None)

    @property
    def totalCylinders(self):
        return self.attributes.get("totalCylinders", None)

    @property
    def totalHeads(self):
        return self.attributes.get("totalHeads", None)

    @property
    def totalSectors(self):
        return self.attributes.get("totalSectors", None)

    @property
    def totalTracks(self):
        return self.attributes.get("totalTracks", None)

    @property
    def tracksPerCylinder(self):
        return self.attributes.get("tracksPerCylinder", None)

    @property
    def sectorsPerTrack(self):
        return self.attributes.get("sectorsPerTrack", None)

    @property
    def firmwareRevision(self):
        return self.attributes.get("firmwareRevision", "")

    @property
    def serialNum(self):
        return self.attributes.get("serialNum", "")

    @property
    def interfaceType(self):
        return self.attributes.get("interfaceType", "")

    @property
    def smartStatus(self):
        return self.attributes.get("smartStatus", "")

    @property
    def temperature(self):
        return self.attributes.get("temperature", None)


class FsSize(BridgeBase):
    @property
    def fs(self):
        return self.attributes.get("fs", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def size(self):
        return self.attributes.get("size", None)

    @property
    def used(self):
        return self.attributes.get("used", None)

    @property
    def available(self):
        return self.attributes.get("available", None)

    @property
    def use(self):
        return self.attributes.get("use", None)

    @property
    def mount(self):
        return self.attributes.get("mount", "")


class Filesystem(BridgeBase):
    @property
    def blockDevices(self) -> Optional[Dict[str, BlockDevices]]:
        return self.attributes.get("blockDevices", {})

    @property
    def diskLayout(self) -> Optional[Dict[str, DiskLayout]]:
        return self.attributes.get("diskLayout", {})

    @property
    def disksIO(self) -> Optional[Dict[str, Any]]:
        return self.attributes.get("disksIO", "")

    @property
    def fsSize(self) -> Optional[Dict[str, FsSize]]:
        return self.attributes.get("fsSize", {})



"""
Class object for BridgeBattery
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 16:49:35.219445
"""
from .base import BridgeBase


class Battery(BridgeBase):
    @property
    def hasBattery(self):
        return self.attributes.get("hasBattery", False)

    @property
    def cycleCount(self):
        return self.attributes.get("cycleCount", None)

    @property
    def isCharging(self):
        return self.attributes.get("isCharging", False)

    @property
    def designedCapacity(self):
        return self.attributes.get("designedCapacity", None)

    @property
    def maxCapacity(self):
        return self.attributes.get("maxCapacity", None)

    @property
    def currentCapacity(self):
        return self.attributes.get("currentCapacity", None)

    @property
    def voltage(self):
        return self.attributes.get("voltage", None)

    @property
    def capacityUnit(self):
        return self.attributes.get("capacityUnit", "")

    @property
    def percent(self):
        return self.attributes.get("percent", None)

    @property
    def timeRemaining(self):
        return self.attributes.get("timeRemaining", None)

    @property
    def acConnected(self):
        return self.attributes.get("acConnected", True)

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def model(self):
        return self.attributes.get("model", "")

    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def serial(self):
        return self.attributes.get("serial", "")



#!/usr/bin/env python
import io

from setuptools import setup, find_packages

version = "0.1.0"

setup(
    name="systembridge",
    version=version,
    description="Python package for connecting to System Bridge.",
    long_description=io.open("README.md", encoding="UTF-8").read(),
    keywords="system bridge connector",
    author="Aidan Timson (Timmo)",
    author_email="contact@timmo.xyz",
    url="https://github.com/timmo001/system-bridge-connector-py",
    packages=find_packages(exclude=["tests", "generator"]),
    install_requires=["aiohttp>=3.7.3"],
)



"""
Class object for Memory
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 17:07:56.628512
"""
from .base import BridgeBase


class Layout(BridgeBase):
    @property
    def size(self):
        return self.attributes.get("size", None)

    @property
    def bank(self):
        return self.attributes.get("bank", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def ecc(self):
        return self.attributes.get("ecc", False)

    @property
    def clockSpeed(self):
        return self.attributes.get("clockSpeed", None)

    @property
    def formFactor(self):
        return self.attributes.get("formFactor", "")

    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def partNum(self):
        return self.attributes.get("partNum", "")

    @property
    def serialNum(self):
        return self.attributes.get("serialNum", "")

    @property
    def voltageConfigured(self):
        return self.attributes.get("voltageConfigured", None)

    @property
    def voltageMin(self):
        return self.attributes.get("voltageMin", None)

    @property
    def voltageMax(self):
        return self.attributes.get("voltageMax", None)


class Memory(BridgeBase):
    @property
    def total(self):
        return self.attributes.get("total", None)

    @property
    def free(self):
        return self.attributes.get("free", None)

    @property
    def used(self):
        return self.attributes.get("used", None)

    @property
    def active(self):
        return self.attributes.get("active", None)

    @property
    def available(self):
        return self.attributes.get("available", None)

    @property
    def buffers(self):
        return self.attributes.get("buffers", None)

    @property
    def cached(self):
        return self.attributes.get("cached", None)

    @property
    def slab(self):
        return self.attributes.get("slab", None)

    @property
    def buffcache(self):
        return self.attributes.get("buffcache", None)

    @property
    def swaptotal(self):
        return self.attributes.get("swaptotal", None)

    @property
    def swapused(self):
        return self.attributes.get("swapused", None)

    @property
    def swapfree(self):
        return self.attributes.get("swapfree", None)

    @property
    def layout(self):
        return [Layout(x) for x in self.attributes.get("layout", [])]
